@@ -92,7 +92,6 @@ setGeneric("subtotalArray", function(x, ...) standardGeneric("subtotalArray"))
 
 setGeneric("types", function(x) standardGeneric("types"))
 setGeneric("timestamps", function(x) standardGeneric("timestamps"))
-
 setGeneric("type", function(x) standardGeneric("type"))
 setGeneric("type<-", function(x, value) standardGeneric("type<-"))
 
@@ -130,8 +129,6 @@ setGeneric("tuple", function(x) standardGeneric("tuple"))
 setGeneric("tuple<-", function(x, value) standardGeneric("tuple<-"))
 setGeneric("ordering", function(x) standardGeneric("ordering"))
 setGeneric("ordering<-", function(x, value) standardGeneric("ordering<-"))
-setGeneric("duplicates", function(x) standardGeneric("duplicates"))
-setGeneric("duplicates<-", function(x, value) standardGeneric("duplicates<-"))
 setGeneric("entity", function(x) standardGeneric("entity"))
 setGeneric("index", function(x) standardGeneric("index"))
 setGeneric("index<-", function(x, value) standardGeneric("index<-"))
@@ -143,6 +140,7 @@ setGeneric("pending", function(x) standardGeneric("pending"))
 setGeneric("permissions", function(x) standardGeneric("permissions"))
 setGeneric("members", function(x) standardGeneric("members"))
 setGeneric("members<-", function(x, value) standardGeneric("members<-"))
+
 setGeneric("multitables", function(x) standardGeneric("multitables"))
 setGeneric("multitables<-", function(x, value) standardGeneric("multitables<-"))
 setGeneric("filters", function(x) standardGeneric("filters"))
@@ -172,12 +170,18 @@ setGeneric("is.derived<-", function(x, value) standardGeneric("is.derived<-"))
 setGeneric("as.Text", function(x, ...) standardGeneric("as.Text"))
 setGeneric("as.Numeric", function(x) standardGeneric("as.Numeric"))
 setGeneric("as.Categorical", function(x, ...) standardGeneric("as.Categorical"))
-setGeneric("as.Datetime", function(x, format = "%Y-%m-%d %H:%M:%S", resolution, offset) standardGeneric("as.Datetime"))
+setGeneric("as.Datetime", function(x,
+                                   format = "%Y-%m-%d %H:%M:%S",
+                                   resolution,
+                                   offset) {
+    standardGeneric("as.Datetime")
+})
 setGeneric("rollupResolution<-", function(x, value) standardGeneric("rollupResolution<-"))
 setGeneric("groupClass", function(x) standardGeneric("groupClass"))
 setGeneric("entityClass", function(x) standardGeneric("entityClass"))
 setGeneric("entitiesInitializer", function(x) standardGeneric("entitiesInitializer"))
 setGeneric("folderExtraction", function(x, tuple) standardGeneric("folderExtraction"))
+setGeneric("personalFolder", function(x) standardGeneric("personalFolder"))
 setGeneric("weightVariables", function(x) standardGeneric("weightVariables"))
 setGeneric("weightVariables<-", function(x, value) standardGeneric("weightVariables<-"))
 setGeneric("is.weightVariable<-", function(x, value) standardGeneric("is.weightVariable<-"))
@@ -208,7 +212,6 @@ setGeneric("dimnames")
 setGeneric("margin.table")
 setGeneric("prop.table")
 setGeneric("round")
-setGeneric("rstandard")
 
 setGeneric("bases", function(x, margin = NULL) standardGeneric("bases"))
 setGeneric("dimensions", function(x) standardGeneric("dimensions"))
