@@ -144,14 +144,11 @@ setMethod("values", "Categories", function(x) vapply(x, value, numeric(1)))
 #' @export
 setMethod("values<-", "Categories", setValues)
 
-#' @rdname is-na-categories
-#' @aliases is-na-categories
-#' @export
-setMethod("is.na", "Categories", function(x) structure(vapply(x, is.na, logical(1), USE.NAMES = FALSE), .Names = names(x)))
-
 #' @rdname is-selected-categories
 #' @export
-setMethod("is.selected", "Categories", function(x) structure(vapply(x, is.selected, logical(1), USE.NAMES = FALSE), .Names = names(x)))
+setMethod("is.selected", "Categories", function(x) {
+    structure(vapply(x, is.selected, logical(1), USE.NAMES = FALSE), .Names = names(x))
+})
 
 #' @rdname is-selected-categories
 #' @export
@@ -160,20 +157,25 @@ setMethod("is.selected<-", "Categories", function(x, value) {
         value <- rep(value, length(x))
     }
     if (length(value) != length(x)) {
-        halt("You supplied ", length(value), " logical values for ", length(x), " Categories.")
+        halt(
+            "You supplied ", length(value), " logical values for ", length(x),
+            " Categories."
+        )
     }
 
     x@.Data <- mapply(function(x, value) {
         is.selected(x) <- value
         return(x)
     }, x = x@.Data, value = value, USE.NAMES = FALSE, SIMPLIFY = FALSE)
-    return(x)
+    return(x) 
 })
 
 #' @rdname is-na-categories
 #' @aliases is-na-categories
 #' @export
-setMethod("is.na", "Categories", function(x) structure(vapply(x, is.na, logical(1), USE.NAMES = FALSE), .Names = names(x)))
+setMethod("is.na", "Categories", function(x) {
+    structure(vapply(x, is.na, logical(1), USE.NAMES = FALSE), .Names = names(x))
+})
 
 #' @rdname is-na-categories
 #' @export
