@@ -288,7 +288,7 @@ setMethod("tuple<-", "CrunchDataset", function(x, value) {
 #' @return a new version of `x`
 #' @name refresh
 #' @aliases refresh
-#' @importFrom httpcache dropCache
+#' @importFrom httpcache dropCache dropOnly
 NULL
 
 #' @rdname refresh
@@ -309,8 +309,6 @@ setMethod("refresh", "CrunchDataset", function(x) {
         new_tuple[intersect(names(new_tuple), names(old_tuple))]
     )
 
-    ## Keep settings in sync
-    duplicates(allVariables(out)) <- duplicates(allVariables(x))
     ## Make sure the activeFilter's dataset_url is also up to date
     filt <- activeFilter(x)
     if (!is.null(filt)) {
