@@ -8,23 +8,23 @@ NULL
 
 #' @rdname hide
 #' @export
-setMethod("hide", "CrunchVariable", function (x) {
+setMethod("hide", "CrunchVariable", function(x) {
     invisible(setTupleSlot(x, "discarded", TRUE))
 })
 #' @rdname hide
 #' @export
-setMethod("hide", "VariableCatalog", function (x) {
+setMethod("hide", "VariableCatalog", function(x) {
     invisible(setIndexSlot(x, "discarded", TRUE))
 })
 
 #' @rdname hide
 #' @export
-setMethod("unhide", "CrunchVariable", function (x) {
+setMethod("unhide", "CrunchVariable", function(x) {
     invisible(setTupleSlot(x, "discarded", FALSE))
 })
 #' @rdname hide
 #' @export
-setMethod("unhide", "VariableCatalog", function (x) {
+setMethod("unhide", "VariableCatalog", function(x) {
     invisible(setIndexSlot(x, "discarded", FALSE))
 })
 
@@ -36,7 +36,7 @@ setMethod("unhide", "VariableCatalog", function (x) {
 #' @return (invisibly) `dataset` with the specified variables (un)hidden
 #' @seealso [`hide`]
 #' @export
-hideVariables <- function (dataset, variables) {
+hideVariables <- function(dataset, variables) {
     var.urls <- urls(allVariables(dataset[variables]))
     allVariables(dataset)[var.urls] <- hide(allVariables(dataset)[var.urls])
     invisible(dataset)
@@ -44,7 +44,7 @@ hideVariables <- function (dataset, variables) {
 
 #' @rdname hideVariables
 #' @export
-`hiddenVariables<-` <- function (x, value) {
+`hiddenVariables<-` <- function(x, value) {
     if (is.character(value)) {
         value <- na.omit(match(value, names(x)))
     }
@@ -57,7 +57,7 @@ hideVariables <- function (dataset, variables) {
 
 #' @rdname hideVariables
 #' @export
-unhideVariables <- function (dataset, variables) {
+unhideVariables <- function(dataset, variables) {
     var.urls <- suppressWarnings(urls(allVariables(dataset[variables])))
     allVariables(dataset)[var.urls] <- unhide(allVariables(dataset)[var.urls])
     invisible(dataset)
@@ -69,11 +69,12 @@ unhideVariables <- function (dataset, variables) {
 #' `getOption("crunch.namekey.dataset")`.
 #' @return a vector of the names of Variables marked as hidden.
 #' @export
-hiddenVariables <- function (dataset, key=namekey(dataset)) {
+hiddenVariables <- function(dataset, key = namekey(dataset)) {
     hv <- hidden(dataset)
     if (length(hv)) {
         return(sort(vapply(index(hv), vget(key), character(1),
-            USE.NAMES=FALSE)))
+            USE.NAMES = FALSE
+        )))
     } else {
         return(c())
     }
