@@ -272,11 +272,10 @@ datetimeFormater <- function(resolution) {
 #'
 #' @keywords internal
 is.TRUEorFALSE <- function(value) {
-    return(is.logical(value) && !is.na(value) && length(value) == 1)
+    return(is.logical(value) && length(value) == 1 && !is.na(value))
 }
-
-escapeQuotes <- function(str) {
-    gsub("'", "\\\\'", str)
+is.singleCharacter <- function(value){
+    return(is.character(value) && length(value) == 1)
 }
 
 #' Check if a user has packages installed
