@@ -12,112 +12,120 @@ NULL
 
 #' @rdname multitable-catalog
 #' @export
-setMethod("multitables", "CrunchDataset", function (x) {
+setMethod("multitables", "CrunchDataset", function(x) {
     MultitableCatalog(crGET(shojiURL(x, "catalogs", "multitables")))
 })
 
 #' @rdname multitable-catalog
 #' @export
-setMethod("multitables<-", "CrunchDataset", function (x, value) x)
+setMethod("multitables<-", "CrunchDataset", function(x, value) x)
 
 #' @rdname catalog-extract
 #' @export
-setMethod("[[", c("MultitableCatalog", "numeric"), function (x, i, ...) {
+setMethod("[[", c("MultitableCatalog", "numeric"), function(x, i, ...) {
     getEntity(x, i, Multitable, ...)
 })
 
 #' @rdname catalog-extract
 #' @export
-setMethod("[[<-", c("MultitableCatalog", "character", "missing", "formula"),
-          function (x, i, j, value) {
-              stopifnot(length(i) == 1)
-              w <- match(i, names(x))
-              ## Creating a new filter if there are no matching names
-              if (is.na(w)) {
-                  f <- newMultitable(formula = value,
-                                     data = loadDataset(datasetReference(x)),
-                                     name = i)
-                  return(refresh(x))
-              }
-              callNextMethod(x, w, value=value)
-          })
+setMethod(
+    "[[<-", c("MultitableCatalog", "character", "missing", "formula"),
+    function(x, i, j, value) {
+        stopifnot(length(i) == 1)
+        w <- match(i, names(x))
+        ## Creating a new filter if there are no matching names
+        if (is.na(w)) {
+            f <- newMultitable(
+                formula = value,
+                data = loadDataset(datasetReference(x)),
+                name = i
+            )
+            return(refresh(x))
+        }
+        callNextMethod(x, w, value = value)
+    }
+)
 
 #' @rdname catalog-extract
 #' @export
-setMethod("[[<-", c("MultitableCatalog", "numeric", "missing", "formula"),
-          function (x, i, j, value) {
-              stopifnot(length(i) == 1)
+setMethod(
+    "[[<-", c("MultitableCatalog", "numeric", "missing", "formula"),
+    function(x, i, j, value) {
+        stopifnot(length(i) == 1)
 
-              ds <- loadDataset(datasetReference(x))
-              template <- formulaToQuery(value, data = ds)
+        ds <- loadDataset(datasetReference(x))
+        template <- formulaToQuery(value, data = ds)
 
-              if (i %in% seq_along(urls(x))) {
-                  payload <- makeMultitablePayload(template = template)
-                  crPATCH(urls(x)[i], body=toJSON(payload))
-                  return(x)
-              } else {
-                  halt("subscript out of bounds: ", i)
-              }
-          })
+        if (i %in% seq_along(urls(x))) {
+            payload <- makeMultitablePayload(template = template)
+            crPATCH(urls(x)[i], body = toJSON(payload))
+            return(x)
+        } else {
+            halt("subscript out of bounds: ", i)
+        }
+    }
+)
 
-makeMultitablePayload <- function (template, ...) {
-    template <- lapply(template$dimensions, function (x) list(query=x))
+makeMultitablePayload <- function(template, ...) {
+    template <- lapply(template$dimensions, function(x) list(query = x))
 
     return(wrapEntity(template = template, ...))
 }
 
 #' @rdname catalog-extract
 #' @export
-setMethod("[[<-", c("MultitableCatalog", "ANY", "missing", "NULL"),
-          function (x, i, j, value) {
-              stopifnot(length(i) == 1)
-              if (is.character(i) && !i %in% names(x)) {
-                  return()
-              } else if (is.numeric(i) && !i %in% seq_along(urls(x))) {
-                  return()
-              }
-              delete(x[[i]])
-              invisible(NULL)
-          })
+setMethod(
+    "[[<-", c("MultitableCatalog", "ANY", "missing", "NULL"),
+    function(x, i, j, value) {
+        stopifnot(length(i) == 1)
+        if (is.character(i) && !i %in% names(x)) {
+            return()
+        } else if (is.numeric(i) && !i %in% seq_along(urls(x))) {
+            return()
+        }
+        delete(x[[i]])
+        invisible(NULL)
+    }
+)
 
 #' @rdname describe
 #' @export
-setMethod("name<-", "Multitable", function (x, value) {
+setMethod("name<-", "Multitable", function(x, value) {
     setEntitySlot(x, "name", value)
 })
 
 #' @export
 #' @rdname describe-catalog
-setMethod("names<-", "MultitableCatalog", function (x, value) {
+setMethod("names<-", "MultitableCatalog", function(x, value) {
     setIndexSlotOnEntity(x, "name", value)
 })
 
 #' @rdname is-public
 #' @export
-setMethod("is.public", "MultitableCatalog", function (x) {
-    getIndexSlot(x, "is_public", what=logical(1))
+setMethod("is.public", "MultitableCatalog", function(x) {
+    getIndexSlot(x, "is_public", what = logical(1))
 })
 
 #' @rdname is-public
 #' @export
-setMethod("is.public<-", "MultitableCatalog", function (x, value) {
-    setIndexSlotOnEntity(x, "is_public", value, what=logical(1))
+setMethod("is.public<-", "MultitableCatalog", function(x, value) {
+    setIndexSlotOnEntity(x, "is_public", value, what = logical(1))
 })
 
 #' @rdname is-public
 #' @export
-setMethod("is.public", "Multitable", function (x) x@body$is_public)
+setMethod("is.public", "Multitable", function(x) x@body$is_public)
 
 #' @rdname is-public
 #' @export
-setMethod("is.public<-", "Multitable", function (x, value) {
+setMethod("is.public<-", "Multitable", function(x, value) {
     stopifnot(is.TRUEorFALSE(value))
     setEntitySlot(x, "is_public", value)
 })
 
 #' @rdname delete
 #' @export
-setMethod("delete", "Multitable", function (x, ...) {
+setMethod("delete", "Multitable", function(x, ...) {
     if (!askForPermission(paste0("Really delete multitable ", dQuote(name(x)), "?"))) {
         halt("Must confirm deleting multitable")
     }
@@ -126,12 +134,12 @@ setMethod("delete", "Multitable", function (x, ...) {
 })
 
 #' @rdname dataset-reference
-setMethod("datasetReference", "Multitable", function (x) {
+setMethod("datasetReference", "Multitable", function(x) {
     datasetReference(self(x))
 })
 
 #' @rdname dataset-reference
-setMethod("datasetReference", "MultitableCatalog", function (x) {
+setMethod("datasetReference", "MultitableCatalog", function(x) {
     datasetReference(self(x))
 })
 
@@ -160,7 +168,7 @@ setMethod("datasetReference", "MultitableCatalog", function (x) {
 #' name(m) # [1] "gender + age4 + marstat"
 #' }
 #' @export
-newMultitable <- function (formula, data, name, ...) {
+newMultitable <- function(formula, data, name, ...) {
     ## Validate inputs
     if (missing(formula)) {
         halt("Must provide a formula")
@@ -176,7 +184,8 @@ newMultitable <- function (formula, data, name, ...) {
 
     payload <- makeMultitablePayload(template = template, name = name)
     u <- crPOST(shojiURL(data, "catalogs", "multitables"),
-                body=toJSON(payload))
+        body = toJSON(payload)
+    )
 
     invisible(Multitable(crGET(u)))
 }
@@ -197,9 +206,9 @@ newMultitable <- function (formula, data, name, ...) {
 #' name(copied_m) # [1] "gender + age4 + marstat"
 #' }
 #' @export
-importMultitable <- function (data, multitable, ...) {
-    payload <- wrapEntity(multitable=self(multitable), ...)
+importMultitable <- function(data, multitable, ...) {
+    payload <- wrapEntity(multitable = self(multitable), ...)
 
-    u <- crPOST(shojiURL(data, "catalogs", "multitables"), body=toJSON(payload))
+    u <- crPOST(shojiURL(data, "catalogs", "multitables"), body = toJSON(payload))
     invisible(Multitable(crGET(u)))
 }
