@@ -353,7 +353,11 @@ catalogToDataFrame <- function(x, keys = TRUE, rownames = NULL,
         }
 
         # Reorder columns to match the order in which keys were supplied
-        out <- out[, keys, drop = FALSE]
+        # Some catalogs get to this point with no columns, subsetting caused
+        # an error in that case.
+        if (ncol(out) > 0) {
+            out <- out[, keys, drop = FALSE]
+        }
         return(out)
     }
 }
