@@ -46,14 +46,18 @@ setMethod("show", "Insertion", .showIt)
 #' @export
 setMethod("show", "Insertions", .showIt)
 
-#' @rdname show-crunch
-#' @export
-setMethod("show", "CrunchProject", .showIt)
-
-
 # Actual show methods
 
-showAbsCategory <- function(x) data.frame(id = id(x), name = name(x), value = value(x), missing = is.na(x), stringsAsFactors = FALSE)
+showAbsCategory <- function(x) {
+    data.frame(
+        id = id(x),
+        name = name(x),
+        value = value(x),
+        missing = is.na(x),
+        stringsAsFactors = FALSE
+    )
+}
+
 showAbsCategories <- function(x) do.call("rbind", lapply(x, showAbsCategory))
 
 showInsertion <- function(x) {
@@ -422,14 +426,3 @@ setMethod("show", "CrunchGeography", function(object) {
 setMethod("getShowContent", "ShojiFolder", function(x) {
     paste0(ifelse(types(x) == "folder", "[+] ", ""), names(x))
 })
-
-setMethod("getShowContent", "CrunchProject", function(x) {
-    # TODO: add number of datasets? folders?
-    return(
-        c(
-            paste0("Project ", dQuote(name(x))),
-            "",
-            showShojiOrder(ordering(x))
-        )
-    )
-})
