@@ -17,7 +17,7 @@ NULL
 
 #' @rdname tuple-methods
 #' @export
-setMethod("refresh", "ShojiTuple", function (x) {
+setMethod("refresh", "ShojiTuple", function(x) {
     dropCache(x@index_url)
     catalog <- ShojiCatalog(crGET(x@index_url))
     tup <- catalog[[x@entity_url]]
@@ -33,65 +33,70 @@ setMethod("refresh", "ShojiTuple", function (x) {
 
 #' @rdname tuple-methods
 #' @export
-setMethod("$", "ShojiTuple", function (x, name) x@body[[name]])
+setMethod("$", "ShojiTuple", function(x, name) x@body[[name]])
 #' @rdname tuple-methods
 #' @export
-setMethod("$<-", "ShojiTuple", function (x, name, value) {
+setMethod("$<-", "ShojiTuple", function(x, name, value) {
     x@body[[name]] <- value
     return(x)
 })
 #' @rdname tuple-methods
 #' @export
-setMethod("[[", "ShojiTuple", function (x, i) x@body[[i]])
+setMethod("[[", "ShojiTuple", function(x, i) x@body[[i]])
 #' @rdname tuple-methods
 #' @export
-setMethod("[[<-", "ShojiTuple", function (x, i, value) {
+setMethod("[[<-", "ShojiTuple", function(x, i, value) {
     x@body[[i]] <- value
     return(x)
 })
 
-setTupleSlot <- function (x, name, value) {
+setTupleSlot <- function(x, name, value) {
     if (!inherits(x, "ShojiTuple")) {
         tuple(x) <- setTupleSlot(tuple(x), name, value)
     } else if (!identical(x[[name]], value)) {
         ## Skip updating if not modified
         x[[name]] <- value
-        payload <- toJSON(structure(list(structure(list(value), .Names=name)),
-            .Names=x@entity_url))
-        crPATCH(x@index_url, body=payload)
+        payload <- toJSON(structure(list(structure(list(value), .Names = name)),
+            .Names = x@entity_url
+        ))
+        crPATCH(x@index_url, body = payload)
     }
     invisible(x)
 }
 
 #' @rdname tuple-methods
 #' @export
-setMethod("self", "ShojiTuple", function (x) x@entity_url)
+setMethod("self", "ShojiTuple", function(x) x@entity_url)
 
 #' @rdname tuple-methods
 #' @export
-setMethod("entity", "VariableTuple", function (x) {
+setMethod("entity", "VariableTuple", function(x) {
     return(VariableEntity(crGET(x@entity_url)))
 })
 
 #' @rdname tuple-methods
 #' @export
-setMethod("entity", "CrunchVariable", function (x) {
+setMethod("entity", "CrunchVariable", function(x) {
     return(VariableEntity(crGET(self(x))))
 })
 #' @rdname tuple-methods
 #' @export
-setMethod("entity", "DatasetTuple", function (x) {
-    return(as.dataset(crGET(x@entity_url), tuple=x))
+setMethod("entity", "DatasetTuple", function(x) {
+    return(as.dataset(crGET(x@entity_url), tuple = x))
 })
 
 #' @rdname tuple-methods
 #' @export
-setMethod("delete", "ShojiTuple", function (x, ...) {
-    crDELETE(x@entity_url, drop=dropCache(x@index_url))
+setMethod("id", "DatasetTuple", function(x) x$id)
+
+#' @rdname tuple-methods
+#' @export
+setMethod("delete", "ShojiTuple", function(x, ...) {
+    crDELETE(x@entity_url, drop = dropCache(x@index_url))
 })
 #' @rdname tuple-methods
 #' @export
-setMethod("delete", "DatasetTuple", function (x, ...) {
+setMethod("delete", "DatasetTuple", function(x, ...) {
     prompt <- paste0("Really delete dataset ", dQuote(name(x)), "?")
     if (!askForPermission(prompt)) {
         halt("Must confirm deleting dataset")
@@ -106,8 +111,10 @@ setMethod("name", "ShojiTuple", vget("name"))
 
 #' @rdname tuple-methods
 #' @export
-setMethod("name<-", "ShojiTuple",
-    function (x, value) setTupleSlot(x, "name", validateNewName(value)))
+setMethod(
+    "name<-", "ShojiTuple",
+    function(x, value) setTupleSlot(x, "name", validateNewName(value))
+)
 
 #' @rdname tuple-methods
 #' @export
