@@ -1,6 +1,6 @@
 ## These are moved from test-variable-folder.R thanks to R's archaic restriction on UTF-8
-expect_output(print(folders(ds), depth=2),
-"/
+expect_output(print(folders(ds), depth = 2),
+    "/
 ├── Group 1/
 │   ├── Birth Year
 │   ├── Nested/
@@ -10,36 +10,40 @@ expect_output(print(folders(ds), depth=2),
 │   └── Text variable ftw
 └── Group 2/
     ├── starttime
-    └── Cat Array", fixed=TRUE
+    └── Cat Array",
+    fixed = TRUE
 )
 
-expect_output(print(folders(ds), depth=1),
-"/
+expect_output(print(folders(ds), depth = 1),
+    "/
 ├── Group 1/
 │   ├── Birth Year
 │   ├── Nested/
 │   └── Text variable ftw
 └── Group 2/
     ├── starttime
-    └── Cat Array", fixed=TRUE
+    └── Cat Array",
+    fixed = TRUE
 )
 
-expect_output(print(folders(ds), pretty=TRUE),
-"/
+expect_output(print(folders(ds), pretty = TRUE),
+    "/
 ├── Group 1/
-└── Group 2/", fixed=TRUE
+└── Group 2/",
+    fixed = TRUE
 )
 
-expect_output(print(folders(ds)[["Group 1/Nested"]], pretty=TRUE),
-"/Group 1/Nested/
+expect_output(print(folders(ds)[["Group 1/Nested"]], pretty = TRUE),
+    "/Group 1/Nested/
 ├── Gender
 ├── Categorical Location
-└── mymrset", fixed=TRUE
+└── mymrset",
+    fixed = TRUE
 )
 
-with(temp.option(crunch.delimiter="|"), {
-    expect_output(print(folders(ds), depth=2),
-"|
+with(temp.option(crunch.delimiter = "|"), {
+    expect_output(print(folders(ds), depth = 2),
+        "|
 ├── Group 1|
 │   ├── Birth Year
 │   ├── Nested|
@@ -49,6 +53,7 @@ with(temp.option(crunch.delimiter="|"), {
 │   └── Text variable ftw
 └── Group 2|
     ├── starttime
-    └── Cat Array", fixed=TRUE
+    └── Cat Array",
+        fixed = TRUE
     )
 })
