@@ -1,10 +1,14 @@
 context("Authentication")
 
 test_that("login checks for email and password before POSTing", {
-    expect_error(crunchAuth(email=NULL),
-        "Must supply the email address associated with your crunch.io account")
-    expect_error(crunchAuth(email=1L, password=NULL),
-        "Must supply a password")
+    expect_error(
+        crunchAuth(email = NULL),
+        "Must supply the email address associated with your crunch.io account"
+    )
+    expect_error(
+        crunchAuth(email = 1L, password = NULL),
+        "Must supply a password"
+    )
 })
 
 test_that("without_echo doesn't crash on this OS", {
@@ -29,13 +33,15 @@ if (run.integration.tests) {
     with(test_options, {
         test_that("crunchAuth succeeds when it should and not when it shouldn't", {
             logout()
-            expect_error(crunchAuth("lkjasdfksdfkjhl", password="w23nrnsod"),
-                "Unable to authenticate lkjasdfksdfkjhl")
+            expect_error(
+                crunchAuth("lkjasdfksdfkjhl", password = "w23nrnsod"),
+                "Unable to authenticate lkjasdfksdfkjhl"
+            )
         })
 
         test_that("login returns a session object", {
             cr <- suppressMessages(login())
-                expect_true(is.list(cr))
+            expect_true(is.list(cr))
             logout()
         })
     })
