@@ -361,12 +361,16 @@ with_mock_crunch({
             ds$gender <- changeCategoryID(ds$gender, "not a numeric", c(1, -1)),
             "from should be a single numeric"
         )
+        expect_error(
+            ds$gender <- changeCategoryID(ds$gender, c(1, -1), 99),
+            "from should be a single numeric"
+        )
         expect_error(
             ds$gender <- changeCategoryID(ds$gender, 1, "not a numeric"),
             "to should be a single numeric"
         )
         expect_error(
-            ds$gender <- changeCategoryID(ds$gender, c(1, -1), "not a numeric"),
+            ds$gender <- changeCategoryID(ds$gender, 99, c(1, -1)),
             "to should be a single numeric"
         )
         expect_error(
