@@ -3,7 +3,7 @@ context("Dataset object and methods")
 with_mock_crunch({
     ds <- loadDataset("test ds")
     ds2 <- loadDataset("ECON.sav")
-    ds3 <- loadDataset("an archived dataset", kind="archived")
+    ds3 <- loadDataset("an archived dataset", kind = "archived")
 
     today <- "2016-02-11"
 
@@ -19,90 +19,118 @@ with_mock_crunch({
     })
 
     test_that("Dataset attribute setting", {
-        expect_PATCH(name(ds) <- "New name",
+        expect_PATCH(
+            name(ds) <- "New name",
             "https://app.crunch.io/api/datasets/",
-            '{"https://app.crunch.io/api/datasets/1/":{"name":"New name"}}')
-        expect_PATCH(notes(ds) <- "Ancillary information",
+            '{"https://app.crunch.io/api/datasets/1/":{"name":"New name"}}'
+        )
+        expect_PATCH(
+            notes(ds) <- "Ancillary information",
             "https://app.crunch.io/api/datasets/1/",
-            '{"notes":"Ancillary information"}')
+            '{"notes":"Ancillary information"}'
+        )
     })
 
     test_that("Population setting", {
         expect_equal(popSize(ds), 90000000)
         expect_equal(popMagnitude(ds), 3)
         expect_no_request(setPopulation(ds, popSize(ds), popMagnitude(ds)))
-        expect_PATCH(setPopulation(ds, size = 6000),
+        expect_PATCH(
+            setPopulation(ds, size = 6000),
             "https://app.crunch.io/api/datasets/1/settings/",
             '{"population":{"magnitude":3,"size":6000}}'
-            )
-        expect_PATCH(setPopulation(ds, magnitude = 6),
+        )
+        expect_PATCH(
+            setPopulation(ds, magnitude = 6),
             "https://app.crunch.io/api/datasets/1/settings/",
             '{"population":{"magnitude":6,"size":90000000}}'
-            )
-        expect_PATCH(setPopulation(ds, size = 6000, magnitude = 6),
+        )
+        expect_PATCH(
+            setPopulation(ds, size = 6000, magnitude = 6),
             "https://app.crunch.io/api/datasets/1/settings/",
             '{"population":{"magnitude":6,"size":6000}}'
-            )
-        expect_PATCH(setPopulation(ds, size = NULL, magnitude = 6),
+        )
+        expect_PATCH(
+            setPopulation(ds, size = NULL, magnitude = 6),
             "https://app.crunch.io/api/datasets/1/settings/",
             '{"population":null}'
-            )
-        expect_PATCH(setPopulation(ds, size = NULL),
+        )
+        expect_PATCH(
+            setPopulation(ds, size = NULL),
             "https://app.crunch.io/api/datasets/1/settings/",
             '{"population":null}'
-            )
-        expect_PATCH(popSize(ds) <- 6000,
+        )
+        expect_PATCH(
+            popSize(ds) <- 6000,
             "https://app.crunch.io/api/datasets/1/settings/",
             '{"population":{"magnitude":3,"size":6000}}'
-            )
-        expect_PATCH(popMagnitude(ds) <- 6,
+        )
+        expect_PATCH(
+            popMagnitude(ds) <- 6,
             "https://app.crunch.io/api/datasets/1/settings/",
             '{"population":{"magnitude":6,"size":90000000}}'
         )
     })
     test_that("setPopulation errors correctly", {
-        expect_error(setPopulation(ds, magnitude = 1000),
-            "Magnitude must be either 3, 6, or 9")
+        expect_error(
+            setPopulation(ds, magnitude = 1000),
+            "Magnitude must be either 3, 6, or 9"
+        )
         expect_error(popMagnitude(ds) <- NULL,
-                     paste0("Magnitude cannot be set to `NULL`. Did you mean ",
-                            "to remove population size with `popSize(x) <- ",
-                            "NULL`?"),
-                     fixed = TRUE)
+            paste0(
+                "Magnitude cannot be set to `NULL`. Did you mean ",
+                "to remove population size with `popSize(x) <- ",
+                "NULL`?"
+            ),
+            fixed = TRUE
+        )
         expect_error(setPopulation(ds, size = 1000, magnitude = NULL),
-                     paste0("Magnitude cannot be set to `NULL`. Did you mean ",
-                            "to remove population size with `popSize(x) <- ",
-                            "NULL`?"),
-                     fixed = TRUE)
+            paste0(
+                "Magnitude cannot be set to `NULL`. Did you mean ",
+                "to remove population size with `popSize(x) <- ",
+                "NULL`?"
+            ),
+            fixed = TRUE
+        )
 
         # setting a population to null that is already null does nothing.
         expect_no_request(popSize(ds2) <- NULL)
 
         expect_error(ds <- setPopulation(ds, size = 12345, magnitude = NULL),
-                     paste0("Magnitude cannot be set to `NULL`. Did you mean ",
-                            "to remove population size with `popSize(x) <- ",
-                            "NULL`?"),
-                     fixed = TRUE)
+            paste0(
+                "Magnitude cannot be set to `NULL`. Did you mean ",
+                "to remove population size with `popSize(x) <- ",
+                "NULL`?"
+            ),
+            fixed = TRUE
+        )
     })
     test_that("setPopulation handles datasets with no population values", {
-        expect_error(setPopulation(ds2, magnitude = 3),
+        expect_error(
+            setPopulation(ds2, magnitude = 3),
             "Dataset does not have a population, please set one before attempting to change magnitude"
-            )
-         expect_warning(
-             expect_PATCH(popSize(ds2) <- 6000,
-                 "https://app.crunch.io/api/datasets/3/settings/",
-                 '{"population":{"magnitude":3,"size":6000}}'
-             ),
-             "Dataset magnitude not set, defaulting to thousands"
-         )
+        )
+        expect_warning(
+            expect_PATCH(
+                popSize(ds2) <- 6000,
+                "https://app.crunch.io/api/datasets/3/settings/",
+                '{"population":{"magnitude":3,"size":6000}}'
+            ),
+            "Dataset magnitude not set, defaulting to thousands"
+        )
     })
 
 
 
     test_that("Name setting validation", {
-        expect_error(name(ds) <- 3.14,
-            'Names must be of class "character"')
-        expect_error(name(ds) <- NULL,
-            'Names must be of class "character"')
+        expect_error(
+            name(ds) <- 3.14,
+            'Names must be of class "character"'
+        )
+        expect_error(
+            name(ds) <- NULL,
+            'Names must be of class "character"'
+        )
     })
 
     test_that("archived", {
@@ -112,12 +140,16 @@ with_mock_crunch({
     })
 
     test_that("archive setting", {
-        expect_PATCH(is.archived(ds2) <- TRUE,
-            'https://app.crunch.io/api/datasets/',
-            '{"https://app.crunch.io/api/datasets/3/":{"archived":true}}')
-        expect_PATCH(archive(ds2),
-            'https://app.crunch.io/api/datasets/',
-            '{"https://app.crunch.io/api/datasets/3/":{"archived":true}}')
+        expect_PATCH(
+            is.archived(ds2) <- TRUE,
+            "https://app.crunch.io/api/datasets/",
+            '{"https://app.crunch.io/api/datasets/3/":{"archived":true}}'
+        )
+        expect_PATCH(
+            archive(ds2),
+            "https://app.crunch.io/api/datasets/",
+            '{"https://app.crunch.io/api/datasets/3/":{"archived":true}}'
+        )
     })
 
     test_that("draft/published", {
@@ -128,21 +160,31 @@ with_mock_crunch({
     })
 
     test_that("draft/publish setting", {
-        expect_PATCH(is.published(ds2) <- TRUE,
-            'https://app.crunch.io/api/datasets/',
-            '{"https://app.crunch.io/api/datasets/3/":{"is_published":true}}')
-        expect_PATCH(is.published(ds) <- FALSE,
-            'https://app.crunch.io/api/datasets/',
-            '{"https://app.crunch.io/api/datasets/1/":{"is_published":false}}')
-        expect_PATCH(is.draft(ds2) <- FALSE,
-            'https://app.crunch.io/api/datasets/',
-            '{"https://app.crunch.io/api/datasets/3/":{"is_published":true}}')
-        expect_PATCH(is.draft(ds) <- TRUE,
-            'https://app.crunch.io/api/datasets/',
-            '{"https://app.crunch.io/api/datasets/1/":{"is_published":false}}')
-        expect_PATCH(publish(ds2),
-            'https://app.crunch.io/api/datasets/',
-            '{"https://app.crunch.io/api/datasets/3/":{"is_published":true}}')
+        expect_PATCH(
+            is.published(ds2) <- TRUE,
+            "https://app.crunch.io/api/datasets/",
+            '{"https://app.crunch.io/api/datasets/3/":{"is_published":true}}'
+        )
+        expect_PATCH(
+            is.published(ds) <- FALSE,
+            "https://app.crunch.io/api/datasets/",
+            '{"https://app.crunch.io/api/datasets/1/":{"is_published":false}}'
+        )
+        expect_PATCH(
+            is.draft(ds2) <- FALSE,
+            "https://app.crunch.io/api/datasets/",
+            '{"https://app.crunch.io/api/datasets/3/":{"is_published":true}}'
+        )
+        expect_PATCH(
+            is.draft(ds) <- TRUE,
+            "https://app.crunch.io/api/datasets/",
+            '{"https://app.crunch.io/api/datasets/1/":{"is_published":false}}'
+        )
+        expect_PATCH(
+            publish(ds2),
+            "https://app.crunch.io/api/datasets/",
+            '{"https://app.crunch.io/api/datasets/3/":{"is_published":true}}'
+        )
         expect_no_request(publish(ds))
         expect_no_request(is.draft(ds) <- FALSE)
         expect_no_request(is.published(ds) <- TRUE)
@@ -156,52 +198,68 @@ with_mock_crunch({
     })
 
     test_that("startDate<- makes correct request", {
-        expect_PATCH(startDate(ds2) <- today,
-            'https://app.crunch.io/api/datasets/',
-            '{"https://app.crunch.io/api/datasets/3/":{"start_date":"2016-02-11"}}')
-        expect_PATCH(startDate(ds) <- NULL,
-            'https://app.crunch.io/api/datasets/',
-            '{"https://app.crunch.io/api/datasets/1/":{"start_date":null}}')
+        expect_PATCH(
+            startDate(ds2) <- today,
+            "https://app.crunch.io/api/datasets/",
+            '{"https://app.crunch.io/api/datasets/3/":{"start_date":"2016-02-11"}}'
+        )
+        expect_PATCH(
+            startDate(ds) <- NULL,
+            "https://app.crunch.io/api/datasets/",
+            '{"https://app.crunch.io/api/datasets/1/":{"start_date":null}}'
+        )
     })
     test_that("endDate<- makes correct request", {
-        expect_PATCH(endDate(ds2) <- today,
-            'https://app.crunch.io/api/datasets/',
-            '{"https://app.crunch.io/api/datasets/3/":{"end_date":"2016-02-11"}}')
-        expect_PATCH(endDate(ds) <- NULL,
-            'https://app.crunch.io/api/datasets/',
-            '{"https://app.crunch.io/api/datasets/1/":{"end_date":null}}')
+        expect_PATCH(
+            endDate(ds2) <- today,
+            "https://app.crunch.io/api/datasets/",
+            '{"https://app.crunch.io/api/datasets/3/":{"end_date":"2016-02-11"}}'
+        )
+        expect_PATCH(
+            endDate(ds) <- NULL,
+            "https://app.crunch.io/api/datasets/",
+            '{"https://app.crunch.io/api/datasets/1/":{"end_date":null}}'
+        )
     })
 
     test_that("Dataset VariableCatalog index is ordered", {
-        expect_identical(urls(variables(ds)),
-            c("https://app.crunch.io/api/datasets/1/variables/birthyr/",
-            "https://app.crunch.io/api/datasets/1/variables/gender/",
-            "https://app.crunch.io/api/datasets/1/variables/location/",
-            "https://app.crunch.io/api/datasets/1/variables/mymrset/",
-            "https://app.crunch.io/api/datasets/1/variables/textVar/",
-            "https://app.crunch.io/api/datasets/1/variables/starttime/",
-            "https://app.crunch.io/api/datasets/1/variables/catarray/"))
+        expect_identical(
+            urls(variables(ds)),
+            c(
+                "https://app.crunch.io/api/datasets/1/variables/birthyr/",
+                "https://app.crunch.io/api/datasets/1/variables/gender/",
+                "https://app.crunch.io/api/datasets/1/variables/location/",
+                "https://app.crunch.io/api/datasets/1/variables/mymrset/",
+                "https://app.crunch.io/api/datasets/1/variables/textVar/",
+                "https://app.crunch.io/api/datasets/1/variables/starttime/",
+                "https://app.crunch.io/api/datasets/1/variables/catarray/"
+            )
+        )
         ## allVariables is ordered too
-        expect_identical(urls(allVariables(ds)),
-            c("https://app.crunch.io/api/datasets/1/variables/birthyr/",
-            "https://app.crunch.io/api/datasets/1/variables/gender/",
-            "https://app.crunch.io/api/datasets/1/variables/location/",
-            "https://app.crunch.io/api/datasets/1/variables/mymrset/",
-            "https://app.crunch.io/api/datasets/1/variables/textVar/",
-            "https://app.crunch.io/api/datasets/1/variables/starttime/",
-            "https://app.crunch.io/api/datasets/1/variables/catarray/"))
+        expect_identical(
+            urls(allVariables(ds)),
+            c(
+                "https://app.crunch.io/api/datasets/1/variables/birthyr/",
+                "https://app.crunch.io/api/datasets/1/variables/gender/",
+                "https://app.crunch.io/api/datasets/1/variables/location/",
+                "https://app.crunch.io/api/datasets/1/variables/mymrset/",
+                "https://app.crunch.io/api/datasets/1/variables/textVar/",
+                "https://app.crunch.io/api/datasets/1/variables/starttime/",
+                "https://app.crunch.io/api/datasets/1/variables/catarray/"
+            )
+        )
     })
 
     test_that("namekey function exists and affects names()", {
         expect_identical(getOption("crunch.namekey.dataset"), "alias")
         expect_identical(names(ds), aliases(variables(ds)))
-        with(temp.option(crunch.namekey.dataset="name"), {
+        with(temp.option(crunch.namekey.dataset = "name"), {
             expect_identical(names(ds), names(variables(ds)))
         })
     })
 
     test_that("Dataset ncol doesn't make any requests", {
-        with(temp.options(httpcache.log=""), {
+        with(temp.options(httpcache.log = ""), {
             logs <- capture.output(nc <- ncol(ds))
         })
         expect_identical(logs, character(0))
@@ -211,15 +269,17 @@ with_mock_crunch({
 
     test_that("Dataset has names() and extract methods work", {
         expect_false(is.null(names(ds)))
-        expect_identical(names(ds),
-            c("birthyr", "gender", "location", "mymrset", "textVar", "starttime", "catarray"))
+        expect_identical(
+            names(ds),
+            c("birthyr", "gender", "location", "mymrset", "textVar", "starttime", "catarray")
+        )
         expect_true(is.variable(ds[[1]]))
         expect_true("birthyr" %in% names(ds))
         expect_true(is.variable(ds$birthyr))
         expect_true(is.dataset(ds[2]))
         expect_identical(ds["gender"], ds[2])
-        expect_identical(ds[,2], ds[2])
-        expect_identical(ds[names(ds)=="gender"], ds[2])
+        expect_identical(ds[, 2], ds[2])
+        expect_identical(ds[names(ds) == "gender"], ds[2])
         expect_identical(names(ds[2]), c("gender"))
         expect_identical(dim(ds[2]), c(25L, 1L))
         expect_null(ds$not.a.var.name)
@@ -227,7 +287,7 @@ with_mock_crunch({
         expect_identical(ds[[self(ds$gender)]], ds$gender)
     })
 
-    with(temp.option(crunch.namekey.dataset="name"), {
+    with(temp.option(crunch.namekey.dataset = "name"), {
         test_that("'namekey' feature (that should be deprecated) is respected", {
             expect_true(is.Numeric(ds$`Birth Year`))
             expect_null(ds$birthyr)
@@ -236,8 +296,8 @@ with_mock_crunch({
 
     test_that("Variables can be extracted by url", {
         url <- urls(variables(ds))[1]
-        expect_identical(ds[[url]], ds[['birthyr']])
-        expect_identical(ds[url], ds['birthyr'])
+        expect_identical(ds[[url]], ds[["birthyr"]])
+        expect_identical(ds[url], ds["birthyr"])
     })
 
     ## This is a start on a test that getting variables doesn't hit server.
@@ -255,48 +315,67 @@ with_mock_crunch({
 
     test_that("Dataset extract error handling", {
         expect_error(ds[[999]], "subscript out of bounds")
-        expect_error(ds[c("gender", "NOTAVARIABLE")],
-            "Undefined columns selected: NOTAVARIABLE")
+        expect_error(
+            ds[c("gender", "NOTAVARIABLE")],
+            "Undefined columns selected: NOTAVARIABLE"
+        )
         expect_null(ds$name)
     })
 
     test_that("Dataset logical extract cases", {
-        expect_null(activeFilter(ds[TRUE,]))
-        expect_error(ds[FALSE,],
-            "Invalid logical filter: FALSE")
-        expect_error(ds[NA,],
-            "Invalid logical filter: NA")
-        expect_null(activeFilter(ds[rep(TRUE, nrow(ds)),]))
-        expect_error(ds[c(TRUE, FALSE),],
-            "Logical filter vector is length 2, but dataset has 25 rows")
-        expect_prints(toJSON(activeFilter(ds[c(rep(FALSE, 4), TRUE,
-            rep(FALSE, 20)),])),
-            paste0('{"function":"==","args":[{"function":"row",',
-            '"args":[]},{"value":4}]}'))
+        expect_null(activeFilter(ds[TRUE, ]))
+        expect_error(
+            ds[FALSE, ],
+            "Invalid logical filter: FALSE"
+        )
+        expect_error(
+            ds[NA, ],
+            "Invalid logical filter: NA"
+        )
+        expect_null(activeFilter(ds[rep(TRUE, nrow(ds)), ]))
+        expect_error(
+            ds[c(TRUE, FALSE), ],
+            "Logical filter vector is length 2, but dataset has 25 rows"
+        )
+        expect_prints(
+            toJSON(activeFilter(ds[c(
+                rep(FALSE, 4), TRUE,
+                rep(FALSE, 20)
+            ), ])),
+            paste0(
+                '{"function":"==","args":[{"function":"row",',
+                '"args":[]},{"value":4}]}'
+            )
+        )
     })
 
     test_that("Extract from dataset by VariableOrder/Group", {
-        ents <- c("https://app.crunch.io/api/datasets/1/variables/gender/",
-            "https://app.crunch.io/api/datasets/1/variables/mymrset/")
-        ord <- VariableOrder(VariableGroup("G1", entities=ents))
+        ents <- c(
+            "https://app.crunch.io/api/datasets/1/variables/gender/",
+            "https://app.crunch.io/api/datasets/1/variables/mymrset/"
+        )
+        ord <- VariableOrder(VariableGroup("G1", entities = ents))
         expect_identical(ds[ord[[1]]], ds[c("gender", "mymrset")])
         expect_identical(ds[ord], ds[c("gender", "mymrset")])
     })
 
     test_that("show method", {
-        expect_identical(getShowContent(ds),
-            c(paste("Dataset", dQuote("test ds")),
-            "",
-            "Contains 25 rows of 7 variables:",
-            "",
-            "$birthyr: Birth Year (numeric)",
-            "$gender: Gender (categorical)",
-            "$location: Categorical Location (categorical)",
-            "$mymrset: mymrset (multiple_response)",
-            "$textVar: Text variable ftw (text)",
-            "$starttime: starttime (datetime)",
-            "$catarray: Cat Array (categorical_array)"
-        ))
+        expect_identical(
+            getShowContent(ds),
+            c(
+                paste("Dataset", dQuote("test ds")),
+                "",
+                "Contains 25 rows of 7 variables:",
+                "",
+                "$birthyr: Birth Year (numeric)",
+                "$gender: Gender (categorical)",
+                "$location: Categorical Location (categorical)",
+                "$mymrset: mymrset (multiple_response)",
+                "$textVar: Text variable ftw (text)",
+                "$starttime: starttime (datetime)",
+                "$catarray: Cat Array (categorical_array)"
+            )
+        )
     })
 
     test_that("dataset can refresh", {
@@ -304,13 +383,13 @@ with_mock_crunch({
     })
 
     test_that("dataset refresh doesn't GET dataset catalog", {
-        with(temp.option(httpcache.log=""), {
+        with(temp.option(httpcache.log = ""), {
             logs <- capture.output({
                 d2 <- refresh(ds)
             })
         })
-        in_logs <- function (str, loglines) {
-            any(grepl(str, loglines, fixed=TRUE))
+        in_logs <- function(str, loglines) {
+            any(grepl(str, loglines, fixed = TRUE))
         }
         expect_false(in_logs("HTTP GET https://app.crunch.io/api/datasets/ 200", logs))
         expect_true(in_logs("CACHE DROP ^https://app[.]crunch[.]io/api/datasets/", logs))
@@ -324,54 +403,65 @@ with_mock_crunch({
     })
 
     test_that("Changing dataset settings", {
-        expect_PATCH(settings(ds)$viewers_can_export <- TRUE,
+        expect_PATCH(
+            settings(ds)$viewers_can_export <- TRUE,
             "https://app.crunch.io/api/datasets/1/settings/",
-            '{"viewers_can_export":true}')
+            '{"viewers_can_export":true}'
+        )
     })
     test_that("No request made if not altering a setting", {
         expect_no_request(settings(ds)$viewers_can_export <- FALSE)
     })
     test_that("Can set a NULL setting", {
-        expect_PATCH(settings(ds)$viewers_can_export <- NULL,
+        expect_PATCH(
+            settings(ds)$viewers_can_export <- NULL,
             "https://app.crunch.io/api/datasets/1/settings/",
-            '{"viewers_can_export":null}')
+            '{"viewers_can_export":null}'
+        )
     })
     test_that("Can set a variable as weight", {
-        expect_PATCH(settings(ds)$weight <- ds$gender, ## Silly; server would reject, but just checking request
+        expect_PATCH(
+            settings(ds)$weight <- ds$gender, ## Silly; server would reject, but just checking request
             "https://app.crunch.io/api/datasets/1/settings/",
-            '{"weight":"https://app.crunch.io/api/datasets/1/variables/gender/"}')
+            '{"weight":"https://app.crunch.io/api/datasets/1/variables/gender/"}'
+        )
     })
     test_that("Can't add a setting that doesn't exist", {
-        expect_error(settings(ds)$NOTASETTING <- TRUE,
-            "Invalid attribute: NOTASETTING")
+        expect_error(
+            settings(ds)$NOTASETTING <- TRUE,
+            "Invalid attribute: NOTASETTING"
+        )
     })
     test_that("Dataset deleting", {
         expect_error(delete(ds), "Must confirm") ## New non-interactive behavior
-        with_consent(expect_DELETE(delete(ds), self(ds)))  ## No warning
+        with_consent(expect_DELETE(delete(ds), self(ds))) ## No warning
     })
 
     test_that("Dashboard URL", {
         expect_null(dashboard(ds))
-        expect_PATCH(dashboard(ds) <- "https://shiny.crunch.io/example/",
+        expect_PATCH(
+            dashboard(ds) <- "https://shiny.crunch.io/example/",
             "https://app.crunch.io/api/datasets/1/",
             '{"app_settings":{"whaam":',
-            '{"dashboardUrl":"https://shiny.crunch.io/example/"}}}')
+            '{"dashboardUrl":"https://shiny.crunch.io/example/"}}}'
+        )
     })
 
     test_that("Primary key methods", {
         expect_null(pk(ds2))
         expect_identical(pk(ds), ds$birthyr)
-        expect_POST(pk(ds) <- ds$textVar,
-            'https://app.crunch.io/api/datasets/1/pk/',
+        expect_POST(
+            pk(ds) <- ds$textVar,
+            "https://app.crunch.io/api/datasets/1/pk/",
             '{"pk":["https://app.crunch.io/api/datasets/1/variables/textVar/"]}'
         )
-        expect_DELETE(pk(ds2) <- NULL, 'https://app.crunch.io/api/datasets/3/pk/')
+        expect_DELETE(pk(ds2) <- NULL, "https://app.crunch.io/api/datasets/3/pk/")
     })
 })
 
 with_test_authentication({
     whereas("When editing dataset metadata", {
-        ds <- createDataset(name=now())
+        ds <- createDataset(name = now())
         test_that("Name and description setters push to server", {
             d2 <- ds
             name(ds) <- "Bond. James Bond."
@@ -382,8 +472,10 @@ with_test_authentication({
             expect_identical(description(refresh(d2)), "007")
             notes(ds) <- "On Her Majesty's Secret Service"
             expect_identical(notes(ds), "On Her Majesty's Secret Service")
-            expect_identical(notes(refresh(d2)),
-                "On Her Majesty's Secret Service")
+            expect_identical(
+                notes(refresh(d2)),
+                "On Her Majesty's Secret Service"
+            )
         })
         test_that("population setters push to server", {
             ds <- setPopulation(ds, 12345, 3)
@@ -452,13 +544,19 @@ with_test_authentication({
         })
 
         test_that("Sending invalid dataset metadata errors usefully", {
-            expect_error(endDate(ds) <- list(foo=4),
-                "must be a string")
-            expect_error(startDate(ds) <- 1985,
-                "must be a string")
+            expect_error(
+                endDate(ds) <- list(foo = 4),
+                "must be a string"
+            )
+            expect_error(
+                startDate(ds) <- 1985,
+                "must be a string"
+            )
             skip("Improve server-side validation")
-            expect_error(startDate(ds) <- "a string",
-                "Useful error message here")
+            expect_error(
+                startDate(ds) <- "a string",
+                "Useful error message here"
+            )
         })
 
         ds$name <- 1:2
@@ -494,15 +592,17 @@ with_test_authentication({
             settings(ds)$weight <- self(ds$name)
             expect_identical(settings(ds)$weight, self(ds$name))
             ## And it should now be in the weight variables order too
-            expect_identical(urls(ShojiOrder(crGET(shojiURL(variables(ds),
-                "orders", "weights")))), self(ds$name))
+            expect_identical(urls(ShojiOrder(crGET(shojiURL(
+                variables(ds),
+                "orders", "weights"
+            )))), self(ds$name))
             ## Can also remove the setting
             settings(ds)$weight <- NULL
             expect_null(settings(ds)$weight)
         })
         test_that("Junk input validation for settings", {
             expect_error(settings(ds)$weight <- self(ds))
-            expect_error(settings(ds)$viewers_can_export <- list(foo="bar"))
+            expect_error(settings(ds)$viewers_can_export <- list(foo = "bar"))
         })
     })
 
@@ -518,27 +618,39 @@ with_test_authentication({
             name(v1) <- "Variable One"
             ds$v1 <- v1
             expect_identical(names(variables(ds))[1], "Variable One")
-            expect_error(ds$v2 <- v1,
-                "Cannot overwrite one Variable")
+            expect_error(
+                ds$v2 <- v1,
+                "Cannot overwrite one Variable"
+            )
         })
     })
 
     with(test.dataset(mrdf), {
         cast.these <- grep("mr_", names(ds))
         test_that("Dataset [<-", {
-            expect_true(all(vapply(variables(ds)[cast.these],
-                function (x) x$type == "numeric", logical(1))))
-            expect_true(all(vapply(ds[cast.these],
-                function (x) is.Numeric(x), logical(1))))
-            ds[cast.these] <- lapply(ds[cast.these],
-                castVariable, "categorical")
-            expect_true(all(vapply(variables(ds)[cast.these],
-                function (x) x$type == "categorical", logical(1))))
-            expect_true(all(vapply(ds[cast.these],
-                function (x) is.Categorical(x), logical(1))))
+            expect_true(all(vapply(
+                variables(ds)[cast.these],
+                function(x) x$type == "numeric", logical(1)
+            )))
+            expect_true(all(vapply(
+                ds[cast.these],
+                function(x) is.Numeric(x), logical(1)
+            )))
+            ds[cast.these] <- lapply(
+                ds[cast.these],
+                castVariable, "categorical"
+            )
+            expect_true(all(vapply(
+                variables(ds)[cast.these],
+                function(x) x$type == "categorical", logical(1)
+            )))
+            expect_true(all(vapply(
+                ds[cast.these],
+                function(x) is.Categorical(x), logical(1)
+            )))
         })
         test_that("Dataset [[<- on new array variable", {
-            ds$arrayVar <- makeArray(ds[cast.these], name="Array variable")
+            ds$arrayVar <- makeArray(ds[cast.these], name = "Array variable")
             expect_true(is.CA(ds$arrayVar))
             expect_identical(name(ds$arrayVar), "Array variable")
         })
