@@ -55,6 +55,7 @@ with_mock_crunch({
     })
 
     f <- filters(ds)[["Occasional Political Interest"]]
+    f_2 <- filters(ds)[["Public filter"]]
     test_that("Filter catalog extract", {
         expect_is(f, "CrunchFilter")
         expect_identical(f, filters(ds)[[1]])
@@ -71,6 +72,32 @@ with_mock_crunch({
         expect_no_request(is.public(f) <- FALSE)
     })
 
+    test_that("can get and set the team for filters", {
+        expect_identical(team(f), getTeams()[["Alpha Team"]])
+        expect_no_request(team(f) <- getTeams()[["Alpha Team"]])
+
+        expect_PATCH(
+            team(f) <- NULL,
+            "https://app.crunch.io/api/datasets/1/filters/filter1/",
+            '{"team":null}'
+        )
+
+        expect_null(team(f_2))
+
+        expect_PATCH(
+            team(f_2) <- getTeams()[["Alpha Team"]],
+            "https://app.crunch.io/api/datasets/1/filters/filter2/",
+            '{"team":"https://app.crunch.io/api/teams/team1/"}'
+        )
+
+        # can also just use a url
+        expect_PATCH(
+            team(f_2) <- "https://app.crunch.io/api/teams/team1/",
+            "https://app.crunch.io/api/datasets/1/filters/filter2/",
+            '{"team":"https://app.crunch.io/api/teams/team1/"}'
+        )
+    })
+
     test_that("Assigning filters<- on a dataset doesn't itself modify anything", {
         expect_no_request(filters(ds) <- filters(ds)[c(2, 1)])
         expect_true(is.dataset(ds))
@@ -257,4 +284,34 @@ with_test_authentication({
             array(c(0, 10), dim = 2L, dimnames = list(v4 = c("B", "C")))
         )
     })
+
+    test_that("team-sharing of filters", {
+        filters(ds)[["team filter"]] <- ds$v4 == "C"
+        team_filter <- filters(ds)[["team filter"]]
+        expect_null(team(team_filter))
+
+        # set teams to use
+        teams <- getTeams()
+        teams[["A new team for filters"]] <- list()
+        teams[["A different team for filters"]] <- list()
+        
+        # can set a team
+        team(team_filter) <- getTeams()[["A new team for filters"]]
+        expect_identical(
+            team(team_filter), 
+            getTeams()[["A new team for filters"]]
+        )
+        
+        # can change a team (with a URL this time)
+        team_url <- self(getTeams()[["A different team for filters"]])
+        team(team_filter) <- team_url
+        expect_identical(
+            team(team_filter),
+            getTeams()[["A different team for filters"]]
+        )
+        
+        # can remove the team
+        team(team_filter) <- NULL
+        expect_null(team(team_filter))
+    })
 })
