@@ -9,11 +9,34 @@ with_mock_crunch({
         ))
         expect_identical(listDatasets("archived"), "an archived dataset")
         expect_identical(listDatasets("all"), c(
-            "ECON.sav", "an archived dataset",
+            "ECON.sav",
+            "an archived dataset",
             "streaming no messages",
-            "streaming test ds", "test ds"
+            "streaming test ds",
+            "test ds"
         ))
     })
+    test_that("listDatasets in project", {
+        expect_identical(listDatasets(project="Project One"),
+            c(
+                "test ds",
+                "streaming no messages"
+            )
+        )
+        expect_identical(listDatasets("all", project="Project One"),
+            c(
+                "an archived dataset",
+                "test ds",
+                "streaming no messages"
+            )
+        )
+        expect_identical(listDatasets(project="Project One/Project Two"),
+            c(
+                "ECON.sav",
+                "streaming test ds"
+            )
+        )
+    })
 
     test_that("loadDataset loads", {
         ## NOTE: implementing the active dataset loading only first
@@ -61,7 +84,7 @@ with_mock_crunch({
     })
 
     test_that("loadDataset by path", {
-        ds3 <- loadDataset("Project One/Group 1/ECON.sav")
+        ds3 <- loadDataset("Project One/Project Two/ECON.sav")
         expect_is(ds3, "CrunchDataset")
         expect_identical(name(ds3), "ECON.sav")
         ds1 <- loadDataset("~/test ds")
@@ -96,48 +119,42 @@ with_mock_crunch({
 })
 
 with_test_authentication({
+    dscat0 <- datasets()
     test_that("datasets() gets the dataset catalog", {
-        col0 <- datasets()
-        expect_is(col0, "DatasetCatalog")
-        with(test.dataset(), {
-            col1 <- datasets()
-            expect_is(col1, "DatasetCatalog")
-            expect_equal(length(col1), length(col0) + 1)
-        })
-    })
-    with(test.dataset(), {
-        dsname <- name(ds)
-        test_that("Dataset list can be retrieved if authenticated", {
-            expect_true(is.character(listDatasets()))
-            expect_true(length(listDatasets()) > 0)
-            expect_true(is.character(dsname))
-            expect_true(nchar(dsname) > 0)
-            expect_true(dsname %in% listDatasets())
-        })
-
-        test_that("A dataset object can be retrieved, if it exists", {
-            expect_true(is.dataset(loadDataset(dsname)))
-            dsnum <- which(listDatasets() %in% dsname)
-            expect_true(is.numeric(dsnum))
-            expect_true(is.dataset(loadDataset(dsnum)))
-        })
+        expect_is(dscat0, "DatasetCatalog")
     })
 
-    with(test.dataset(), {
-        dsname <- name(ds)
-        newname <- paste0("New name ", now())
+    ds <- createDataset(name = now())
+    dsname <- name(ds)
+    test_that("Adding a dataset refreshes the list", {
+        expect_equal(length(datasets()), length(dscat0) + 1)
+    })
 
-        test_that("renaming a dataset refreshes the dataset list", {
-            expect_true(dsname %in% listDatasets())
-            name(ds) <- newname
-            expect_false(dsname %in% listDatasets())
-            expect_true(newname %in% listDatasets())
-        })
+    test_that("Dataset list can be retrieved if authenticated", {
+        expect_true(is.character(listDatasets()))
+        expect_true(length(listDatasets()) > 0)
+        expect_true(is.character(dsname))
+        expect_true(nchar(dsname) > 0)
+        expect_true(dsname %in% listDatasets())
+    })
 
-        test_that("deleting a dataset refreshes the dataset list", {
-            with_consent(delete(ds))
-            expect_false(dsname %in% listDatasets())
-            expect_false(newname %in% listDatasets())
-        })
+    test_that("A dataset object can be retrieved, if it exists", {
+        expect_true(is.dataset(loadDataset(dsname)))
+        dsnum <- which(listDatasets() %in% dsname)
+        expect_true(is.numeric(dsnum))
+        expect_true(is.dataset(loadDataset(dsnum)))
+    })
+
+    newname <- paste0("New name ", now())
+    test_that("renaming a dataset refreshes the dataset list", {
+        name(ds) <- newname
+        expect_false(dsname %in% listDatasets())
+        expect_true(newname %in% listDatasets())
+    })
+
+    test_that("deleting a dataset refreshes the dataset list", {
+        with_consent(delete(ds))
+        expect_false(dsname %in% listDatasets())
+        expect_false(newname %in% listDatasets())
     })
 })
