@@ -3,20 +3,11 @@ context("Projects")
 with_mock_crunch({
     projects <- session()$projects
     test_that("Getting projects catalog", {
-        expect_is(projects, "ProjectCatalog")
+        expect_is(projects, "ProjectFolder")
         expect_length(projects, 2)
-        expect_identical(names(projects), c("Project One", "Project Two"))
+        expect_identical(names(projects), c("Project One", "Project Three"))
     })
 
-    test_that("ProjectCatalog print (as.data.frame) method", {
-        expect_identical(dim(as.data.frame(projects)), c(2L, 3L))
-        expect_identical(
-            names(as.data.frame(projects)),
-            c("name", "id", "description")
-        )
-    })
-
-    aproject <- projects[["Project One"]]
     test_that("Getting project from catalog", {
         expect_true(is.project(projects[[1]]))
         expect_true(is.project(projects$`Project One`))
@@ -24,20 +15,22 @@ with_mock_crunch({
         expect_null(projects$`Beta Project`)
     })
 
+    aproject <- projects[["Project One"]]
     test_that("Project attributes", {
         expect_identical(name(aproject), "Project One")
     })
 
+    creation <- '{"element":"shoji:entity","body":{"name":"A new project"}}'
     test_that("Simple project creation by assignment", {
         expect_POST(
             projects[["A new project"]] <- list(),
             "https://app.crunch.io/api/projects/",
-            '{"name":"A new project"}'
+            creation
         )
         expect_POST(
             projects$`A new project` <- list(),
             "https://app.crunch.io/api/projects/",
-            '{"name":"A new project"}'
+            creation
         )
     })
 
@@ -45,7 +38,7 @@ with_mock_crunch({
         expect_POST(
             newProject("A new project"),
             "https://app.crunch.io/api/projects/",
-            '{"name":"A new project"}'
+            creation
         )
         with_POST("https://app.crunch.io/api/projects/project1/", {
             ## Mock the return of that creation
@@ -65,19 +58,20 @@ with_mock_crunch({
         expect_PATCH(
             names(projects)[2] <- "New name",
             "https://app.crunch.io/api/projects/",
-            '{"element":"shoji:catalog","index":{"https://app.crunch.io/api/projects/project2/":{"name":"New name"}}}'
+            '{"element":"shoji:catalog","index":',
+            '{"https://app.crunch.io/api/projects/project3/":{"name":"New name"}}}'
         )
         expect_PATCH(
             name(projects[[2]]) <- "New name",
-            "https://app.crunch.io/api/projects/",
-            '{"https://app.crunch.io/api/projects/project2/":{"name":"New name"}}'
+            "https://app.crunch.io/api/projects/project3/",
+            '{"name":"New name"}'
         )
     })
 
     test_that("Project deletion", {
         expect_error(
             delete(projects[[1]]),
-            "Must confirm deleting project"
+            "Must confirm deleting folder"
         )
         with(consent(), {
             expect_DELETE(delete(projects[[1]]), "https://app.crunch.io/api/projects/project1/")
@@ -164,11 +158,11 @@ with_mock_crunch({
     })
 
     test_that("Can loadDataset from a project dataset catalog", {
-        ds <- loadDataset("ECON.sav", project = aproject)
+        ds <- loadDataset("test ds", project = aproject)
         expect_is(ds, "CrunchDataset")
-        expect_identical(name(ds), "ECON.sav")
+        expect_identical(name(ds), "test ds")
         expect_identical(
-            loadDataset("ECON.sav", project = "Project One"),
+            loadDataset("test ds", project = "Project One"),
             ds
         )
     })
@@ -176,7 +170,7 @@ with_mock_crunch({
     test_that("loadDataset project arg error handling", {
         expect_error(
             loadDataset("foo", project = 12),
-            "subscript out of bounds"
+            "Project 12 is not valid"
         )
         expect_error(
             loadDataset("foo", project = "Not a project"),
@@ -197,69 +191,25 @@ with_mock_crunch({
         )
     })
 
-    test_that("Add datasets to project by <- a dataset (which transfers ownership)", {
-        ds <- loadDataset("test ds")
+    test_that("Add datasets to project by <- a dataset (which calls mv)", {
+        ds <- loadDataset("ECON.sav")
         expect_PATCH(
             datasets(aproject) <- ds,
-            "https://app.crunch.io/api/datasets/1/",
-            '{"owner":"https://app.crunch.io/api/projects/project1/"}'
+            "https://app.crunch.io/api/projects/project1/"
         )
     })
-
-    test_that("Organize datasets", {
-        options(crunch.already.shown.ds.order.msg = NULL) ## To make sure the warning fires
-        expect_identical(
-            DatasetOrder(DatasetGroup("new group", datasets(aproject))),
-            DatasetOrder(DatasetGroup("new group", "https://app.crunch.io/api/datasets/3/"))
-        )
-        expect_warning(
-            expect_PUT(
-                ordering(datasets(aproject)) <- DatasetOrder(DatasetGroup(
-                    "new group",
-                    datasets(aproject)
-                )),
-                "https://app.crunch.io/api/projects/project1/datasets/order/",
-                '{"graph":[{"new group":["https://app.crunch.io/api/datasets/3/"]}]}'
-            ),
-            "Greetings!"
-        )
-        nested.ord <- DatasetOrder("https://app.crunch.io/api/datasets/3/",
-            DatasetGroup(
-                "new group",
-                list(DatasetGroup("nested", "https://app.crunch.io/api/datasets/3/"))
-            ),
-            duplicates = TRUE
-        )
-        ## Can also set on the project directly too
-        expect_warning(
-            expect_PUT(
-                ordering(aproject) <- nested.ord,
-                "https://app.crunch.io/api/projects/project1/datasets/order/",
-                '{"graph":["https://app.crunch.io/api/datasets/3/",',
-                '{"new group":[{"nested":["https://app.crunch.io/api/datasets/3/"]}]}]}'
-            ),
-            ## This one doesn't warn because it only warns the first time!
-            NA
-        )
+    test_that("Add datasets to project by <- does nothing if already present", {
+        ds <- loadDataset("test ds")
+        expect_no_request(datasets(aproject) <- ds)
     })
 
-    test_that("Organize datasets cleans up unexpected entries", {
-        neword <- DatasetOrder(
-            DatasetGroup(
+    test_that("Organize datasets is gone!", {
+        expect_error(
+            ordering(aproject) <- DatasetOrder(DatasetGroup(
                 "new group",
-                c(
-                    "https://app.crunch.io/api/datasets/3/",
-                    "https://app.crunch.io/api/datasets/1/"
-                )
-            )
-        )
-        expect_warning(
-            expect_PUT(
-                ordering(datasets(aproject)) <- neword,
-                "https://app.crunch.io/api/projects/project1/datasets/order/",
-                '{"graph":[{"new group":["https://app.crunch.io/api/datasets/3/"]}]}'
-            ),
-            "Order contained dataset URL not found in the catalog. It has been automatically cleaned."
+                datasets(aproject)
+            )),
+            "Hi there!"
         )
     })
 })
@@ -271,7 +221,7 @@ with_test_authentication({
 
     nprojects.0 <- length(myprojects)
     test_that("Can get project catalog", {
-        expect_is(myprojects, "ProjectCatalog")
+        expect_is(myprojects, "ProjectFolder")
     })
 
     name.of.project1 <- now()
@@ -391,78 +341,6 @@ with_test_authentication({
         expect_true(is.dataset(ds2))
         expect_identical(self(ds2), self(ds))
     })
-    test_that("Can organize datasets", {
-        expect_identical(
-            as.list(urls(datasets(tp))),
-            entities(ordering(datasets(tp)))
-        )
-        ordering(datasets(tp)) <- DatasetOrder(DatasetGroup(
-            "A group of one",
-            list(ds)
-        ))
-        expect_identical(
-            ordering(datasets(tp))@graph[[1]],
-            DatasetGroup(name = "A group of one", entities = self(ds))
-        )
-    })
-    ds3 <- createDataset(name = now())
-    ord2 <- DatasetOrder(DatasetGroup(
-        "A group of two",
-        c(self(ds), self(ds3))
-    ))
-    owner(ds3) <- tp
-    tp <- refresh(tp)
-    test_that("Can reorganize datasets", {
-        ordering(datasets(tp)) <- ord2
-        expect_identical(
-            ordering(datasets(tp))@graph[[1]],
-            DatasetGroup(
-                name = "A group of two",
-                entities = c(self(ds), self(ds3))
-            )
-        )
-        expect_prints(ordering(datasets(tp)),
-            paste("[+] A group of two",
-                paste0("    ", name(ds)),
-                paste0("    ", name(ds3)),
-                sep = "\n"
-            ),
-            fixed = TRUE
-        )
-    })
-    ord3 <- DatasetOrder(
-        DatasetGroup("G1", self(ds3)),
-        DatasetGroup("G2", self(ds))
-    )
-    ord3.list <- list(
-        DatasetGroup("G1", self(ds3)),
-        DatasetGroup("G2", self(ds))
-    )
-    ord3.alt <- DatasetOrder(
-        DatasetGroup("G1", datasets(tp)[names(datasets(tp)) == name(ds3)]),
-        DatasetGroup("G2", datasets(tp)[names(datasets(tp)) == name(ds)])
-    )
-    test_that("Can re-reorganize", {
-        expect_identical(ord3, ord3.alt)
-        ordering(datasets(tp)) <- ord3
-        expect_identical(ordering(datasets(tp))@graph, ord3.list)
-        expect_identical(ordering(datasets(refresh(tp)))@graph, ord3.list)
-    })
-
-    test_that("Can create a Group by assigning by name", {
-        ordering(datasets(tp))[["New group three"]] <- self(ds)
-        expect_prints(ordering(datasets(tp)),
-            paste("[+] G1",
-                paste0("    ", name(ds3)),
-                "[+] G2",
-                "    (Empty group)",
-                "[+] New group three",
-                paste0("    ", name(ds)),
-                sep = "\n"
-            ),
-            fixed = TRUE
-        )
-    })
 
     test_that("Can rename a dataset in a project", {
         newname <- paste(name(ds2), "edited")
